@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 # test_peertitles.py
 """Tests for peertitles."""
 import os
@@ -7,7 +8,7 @@ from context import peertitles
 
 
 def test_peertitles_is_dict():
-    os.remove('./persontitles/peertitles.json')
+    os.remove('./persontitles/data/peertitles.json')
     PEERTITLES = peertitles.peertitles()
     assert isinstance(PEERTITLES, dict)
 
