@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 # test_uk.py
 """Tests for academic_uk module."""
 import os
@@ -7,15 +8,15 @@ from context import academic_uk
 
 
 def test_filenotfound():
-    os.remove('./persontitles/academic_uk.txt')
+    os.remove('./persontitles/data/academic_uk.txt')
     ACADEMIC = academic_uk.degrees_uk()
-    assert isinstance(ACADEMIC, set)
+    assert isinstance(ACADEMIC, list)
 
 
 def test_academic_is_set():
 
     ACADEMIC = academic_uk.degrees_uk()
-    assert isinstance(ACADEMIC, set)
+    assert isinstance(ACADEMIC, list)
 
 
 def test_degree_in_list():
